/* Copyright (c) 1996 by Stanford University.  All Rights Reserved */

/***************************************************************************
   NAME

   PURPOSE
     
   NOTES
     
   AUTHOR
     David Hsu  
   
     dyhsu@cs.stanford.edu
     http://robotics.stanford.edu/~dyhsu 
                  
   HISTORY

***************************************************************************/


#ifndef _BASICPLANNER_H
#define _BASICPLANNER_H

#include <iostream.h>
#include "utilities.H"
#include "config.H"
#include "robot.H"
#include "obstacle.H"
#include "cspace.H"

/* BasicPlanner
 *   abstract base class
 *   provide bookkeeping for planner
 */

class BasicPlanner {
    friend istream& operator>> (istream& is, BasicPlanner& p);
    friend ostream& operator<< (ostream& os, BasicPlanner& p);

public:
    Robot r;				/* robot in workspace */
    Obstacle obs;			/* obstacle in workspace */
    Cspace csp;				/*  c-space */

    void bgn(istream& rsrc, istream& osrc, istream &asrc);
    void end() {}
    virtual void query(ostream& pfile)=0;
    virtual void query(Config& ic, Config& gc, ostream& pfile);

protected:
    Config init;			/* init config  */
    Config goal;			/* goal config  */
    Bool   found;			/* path found */

    void writePath(PtrConfig ic, PtrConfig gc, ostream& os);
    void smoothPath(PtrConfig* path, int n);
};



#endif /* _BASICPLANNER_H */
