/* Copyright (c) 1996 by Stanford University.  All Rights Reserved */

/***************************************************************************
   NAME

   PURPOSE
     
   NOTES
     
   AUTHOR
     David Hsu  
   
     dyhsu@cs.stanford.edu
     http://robotics.stanford.edu/~dyhsu 
                  
   HISTORY

***************************************************************************/


#include "global.H"
#include "config.H"
#include "cspace.H"


/* interpolate
 *   interpolate the config's p and q until the resolution specfied by csp
 *   is reached
 *   return the interpolated values in a ConfigArray dynamically allocated
 *   on the heap. It's caller's resposibility to deallocate it.
 */

ConfigArray* interpolate(Config& p, Config& q, Robot& robo)
{
    int s,j,k;

    // calculate the step size
    p.antipode(q);
    s = wdist(p,q, robo.radius()) / Ct.ITPL_RES;


    float stepSize[DIM];
    for (j = 0; j < DIM; j++) 
	stepSize[j] = (q[j] - p[j]) / s;

    // interpolate the two config's
    ConfigArray* path = new ConfigArray(s+1);    
    for (k = 0; k < s+1; k++)  {
	for (j=0; j < DIM; j++) {
	    (*(*path)[k])[j] = p[j] + stepSize[j] * k;
	}
//	(*path)[k]->normalize();
    }
    return path;
}


istream& operator>> (istream& is, Coords& c)
{
    for (int i=0; i < DIM; i++)
	is >> c.q[i];
    return is;
}

ostream& operator << (ostream& os, Coords& c )
{
    for (int i=0; i < 3; i++ )
	os << c.q[i] << ' ';
    os << '\t';
    for (; i < DIM; i++)
	os << c.q[i] << ' ';
    return os;
}




