/* Copyright (c) 1996 by Stanford University.  All Rights Reserved */

/***************************************************************************
   NAME

   PURPOSE
     define a extensible array of config's

   NOTES
     
   AUTHOR
     David Hsu  
   
     dyhsu@cs.stanford.edu
     http://robotics.stanford.edu/~dyhsu 
                  
   HISTORY
     created July, 1996

***************************************************************************/


#include <string.h>
#include "configArray.H"
#include "config.H"
#include "utilities.H"

ConfigArray::ConfigArray(int s)
{
  if (s > 0) {
    v = new Config[sz=s];      /* allocate memory */
    p = new PtrConfig[sz];

    for (int i=0; i < sz;i++)
      p[i] = v + i;
  }
}

ConfigArray::~ConfigArray()
{
  delete [] p; delete [] v;
}

/* resize
 *    resize the array
 *  
 *    nsize : new size
 */

void ConfigArray::resize(unsigned nsize)
{
   
  if (nsize <= sz)
    return;

  PtrConfig* np = new PtrConfig[nsize];	  /* allocate new memory */
  Config* nv = new Config[nsize];

  if (np == NULL || nv == NULL)
    error("ConfigArray::resize : out of memory !");

  memcpy( nv, v, sz * sizeof(Config) );   /* copy over */ 
  for (int i=0; i < sz; i++) {
    np[i] = nv +  (p[i] - v);		  /* fix up pointers */
    np[i]->link = (p[i]->link == NULL) ? NULL: nv + (p[i]->link - v);
  }
  for (; i < nsize; i++)
    np[i] = nv + i;

  delete [] p;				  /* delete old memory */
  delete [] v;

  sz = nsize; v = nv; p = np;
}


/* printOmitLast
 *   print every config in the array except the last one
 */

void ConfigArray::printOmitLast(ostream& os)
{
  for (int i=0; i < size()-1  ; i++)
    os <<  (*p[i])  << endl;
}

ostream& operator<<(ostream& os, ConfigArray& ca)
{
  for (int i=0; i < ca.size() ; i++)
    os << (*(ca[i])) << endl;
  return os;
}
