/* Copyright (c) 1996 by Stanford University.  All Rights Reserved */

/***************************************************************************
   NAME

   PURPOSE
     
   NOTES
     
   AUTHOR
     David Hsu  
   
     dyhsu@cs.stanford.edu
     http://robotics.stanford.edu/~dyhsu 
                  
   HISTORY

***************************************************************************/


#ifndef _CSPACE_H
#define _CSPACE_H

#include "utilities.H"
#include "config.H"


class Cspace;				/* forward decl */

/* SampleBox
 *    define the size of the box used for sampling
 */

class SampleBox: public Coords {
public:
    SampleBox() { for (int i=0; i<DIM; i++) q[i]=.0;}
    SampleBox(float len, Coord param, Cspace& csp);
    Coord* box() { return coords(); }
};


/* Cspace
 *    configuration cspace of the robot
 */

class Cspace {
    friend istream& operator>>(istream& is, Cspace& b);
    friend ostream& operator<<(ostream& os, Cspace& b);
public:
    Coords l;				/* left  boundary of box */
    Coords r;				/* right boundary of box */
/*    Coords step;			   discretization: 
					   Details of c-space below this
					   resolution are ignored by the
					   collision checker     
    Coords istep;			   discretization:
					   used when interpolating
					   the final path       

    void res(Coord incr, Coord param);
    void ires(Coord incr, Coord param);
    const Coord res(int i) {return step[i];}
    const Coord ires(int i) {return istep[i]; } */
    inline Bool sample(Config& origin,SampleBox& box, Config& s);
    inline Bool sample(Config& origin, Config& s, float param);
    inline static void sampleDir(Coords& dir);
};

#endif /* _CSPACE_H */
