/* Copyright (c) 1996 by Stanford University.  All Rights Reserved */

/***************************************************************************
   NAME

   PURPOSE
     
   NOTES
     
   AUTHOR
     David Hsu  
   
     dyhsu@cs.stanford.edu
     http://robotics.stanford.edu/~dyhsu 
                  
   HISTORY

***************************************************************************/


#include <fstream.h>
#include <sys/types.h>
#include <time.h>
#include "ctrl.H"
#include "utilities.H"

static long seeds[] = {
  1000003,1100009,1200007,1300021,1400017,1500007,1600033,1700021,1800017,
  1900009,2000003,2100001,2200013,2300003,2400001,2500009,2600011,2700023,
  2800001,2900017,3000017,3100007,3200003,3300001,3400043,3500017,3600001,
  3700001,3800021,3900067,4000037,4100011,4200013,4300003,4400021,4500007,
  4600003,4700021,4800007,4900001,5000011,5100071,5200007,5300003,5400001,
  5500003,5600027,5700007,5800019,5900047,6000011,6100001,6200003,6300011,
  6400013,6500003,6600001,6700007,6800033,6900001,7000003,7100003,7200007,
  7300001,7400011,7500013,7600013,7700071,7800017,7900001,8000009,8100073,
  8200007,8300009,8400011,8500007,8600023,8700001,8800009,8900029,9000011,
  9100009,9200017,9300001,9400009,9500021,9600037,9700003,9800003,9900047,
  10000019 };

istream& operator>> (istream& is, Controller& ct)
{
    is >> ct.rmax >> ct.distErr
       >> ct.tol  >> ct.WRK_SPC_RES
       >> ct.iseed >> ct.fseed
       >> ct.boxSize >> ct.expNum
       >> ct.branchFac >>  ct.lambda 
       >> ct.cNum >> ct.cDist >> ct.MAX_ITER 
       >> ct.ITPL_RES;

    int ind = time(NULL) % 91;
    cerr << "S: seed = " << seeds[ind] << endl;
    randInt.seed( seeds[ind] );
    randDbl.seed( seeds[ind] );

    return is;
}

ostream& operator<< (ostream& os, Controller& ct)
{
    os << "Program parameters:\n ";

    os << "\t radius of covering ball \t= " << ct.rmax << "\n" ;
    os << "\t error in distance computation\t= " <<int(ct.distErr*100) 
         <<" %\n"; 
    os << "\t collision tolerance\t\t= " << ct.tol << "\n";
    os << "\t resolution of workspace\t= " << ct.WRK_SPC_RES << "\n\n";

    os << "\t sampling box size\t\t= " << ct.boxSize << "\n";
    os << "\t branch factor\t\t\t= " << ct.branchFac << "\n";
    os << "\t lambda of heuristic function\t= " << ct.lambda << "\n";
    os << "\t number of nodes selected for expansion per iteration\t= " << 
            ct.expNum << "\n";
    os << "\t average number of connections tried for each node\t= "
         << ct.cNum << "\n";
    os << "\t max distance for connection attempt \t\t\t= "
         << ct.cDist << "\n";
    
    os << "\t maximum number of iterations\t= " << ct.MAX_ITER << "\n\n";

    return os;
}
