/* Copyright (c) 1996 by Stanford University.  All Rights Reserved */

/***************************************************************************
   NAME
     Ctrl

   PURPOSE
     control the behavior of planner

   NOTES
     
   AUTHOR
     David Hsu  
   
     dyhsu@cs.stanford.edu
     http://robotics.stanford.edu/~dyhsu 
                  
   HISTORY
     created July, 1996

***************************************************************************/


#ifndef _CTRL_H
#define _CTRL_H

#include <iostream.h>

class Controller {
    friend istream& operator>> (istream& is, Controller& ct);
    friend ostream& operator<< (ostream& os, Controller& ct);

public:
    // parameters controlling the collision cheching
    float rmax;                       /* max radius of covering ball */
    float distErr;                    /* error allowed in dist. computation */
    float tol;                        /* threshhold for colllision checking
                                         report collision if dist <= tol   */
    float WRK_SPC_RES;                /* resolution of workspace, features
                                         below this resolution  is ignored
                                         by the collision checking */

    // parameters controlling the sampling and connection
    long iseed;			      /* seed for integer rand generator */
    long fseed;			      /* seed for fp rand generator */
    float boxSize;                    /* size of sampling box */
    int  expNum;                      /* select expNum nodes for expansion 
                                         per iteration */
    int  branchFac;                   /* branch factor of the tree */
    float  lambda;		      /* weight in the heuristic function */
/*    int  nicety;                        nicety of node in order to be 
                                         installed in tree
                                         0 <= nicety <= 100   

    int  difficulty;                    difficulty of node in order to be
                                         installed in tree  */
    int  cNum;                        /* for each node in one component, try
                                         to connect with cNum nodes in the
                                         other component*/
    float cDist;		      /* try to connect two nodes if their
					 dist in workspace < cDist */
    int  MAX_ITER;                    /* max number of iterations  */

    // paremeter controlling the output
    float ITPL_RES;                   /* resolution for interpolating the
				         final path */
    int sm;                           /* whether to smmoth the path */
    int it;                           /* whether to interpolate the final  */
    int tr;                           /* whether to print the execution trace*/
    int uni;			      /* expand only from the init config */

    Controller() {sm = it = tr = uni = 0;}
};


#endif /* _CTRL_H */
