/* Copyright (c) 1996 by Stanford University.  All Rights Reserved */

/***************************************************************************
   NAME
     Stat

   PURPOSE
     keep track of program stats

   NOTES
     
   AUTHOR
     David Hsu  
   
     dyhsu@cs.stanford.edu
     http://robotics.stanford.edu/~dyhsu 
                  
   HISTORY
     created July, 1996

***************************************************************************/


#ifndef _STAT_H
#define _STAT_H

#include <iostream.h>
#include <sys/types.h>
#include <sys/times.h>


class Statistics {
    friend ostream& operator<< (ostream& os, Statistics& s);

public:
    unsigned long totalRawSample;       /* total number of rand. config's 
					   picked */
    unsigned long totalSample;		/* total number of samples placed
					   in c-space */
    unsigned long totalFree;            /* number of samples in C-free */
    unsigned long totalFreeCnt;		/* number of free samples that
					   are connected to the comp.  */
    unsigned long iWhite;               /* total config's connected to 
                                           initial config */
    unsigned long iGray;                /* total config's connected to 
                                           initial config that are expanded*/
    unsigned long iDead;                /* number of dead nodes connected to
                                           initial config */
    unsigned long gWhite;               /* total config's connected to 
                                           goal config */
    unsigned long gGray;                /* total config's connected to 
                                           initial config that are expanded*/
    unsigned long gDead;                /* number of dead nodes connected to
                                           goal config */

    unsigned long numColCheck;          /* total number of collision checks */
    unsigned long numConnection;        /* number of connections attempted
					   cross components */
    unsigned long numLink;              /* number of connections attempted
                                           bewteen two nodes (within same
					   component */
    unsigned long numConnectPair;	/* number of calls to connectPair */
    struct tms       qStart;            /* query start time  */
    struct tms       qEnd;              /* query finish time */

    int numIter;			/* number of iterations executed */
    char	robotName[64];		/* name of robot       */
    char 	obsName[64];		/* name of environment */

    void reset();
};

#endif   /* _STAT_H */
